@@ -1,7 +1,7 @@
 eigenPCA <- function(data,tol=.Machine$double.eps)
   {
-    center1 <- apply(data,2,mean)
-    datascale <- apply(data,2,scale,scale=FALSE)
+    center1 <- colMeans(data,2,mean)
+    datascale <- scale(data,2,scale=FALSE)
     eigData <- eigen(cov(datascale),symmetric=TRUE)
     eigData$values <- eigData$values[which(eigData$values > tol)] 
     sdev <- sqrt(eigData$values)
