@@ -5,7 +5,8 @@
 #' @param x k x 3 matrix or mesh3d
 #' @param icpiter integer: number of iterations to match reflected configuration onto original one
 #' @param subsample integer: use only a subset for icp matching
-#'
+#' @param pcAlign if TRUE, the icp will be preceeded by an alignment of the principal axis (only used if icpiter > 0).
+#' @param mc.cores use parallel processing to find best alignment to original shape.
 #' @details reflect a mesh configuration at the plane spanned by its first 2 principal axis, then try to rigidily register the reflected configuration onto the original one using iterative closest point search to establish correspondences.
 #' @return returns the reflected object
 #' @examples
@@ -25,41 +26,31 @@
 #' wire3d(skullMir,col=2)
 #' }
 #' @rdname mirror
+#' @importFrom rgl rotationMatrix
 #' @export
-mirror <- function(x,icpiter=50,subsample=NULL) UseMethod("mirror")
+mirror <- function(x,icpiter=50,subsample=NULL,pcAlign=TRUE,mc.cores=2) UseMethod("mirror")
 
 #' @rdname mirror
 #' @export
-mirror.matrix <- function(x,icpiter=50,subsample=NULL) {
+mirror.matrix <- function(x,icpiter=50,subsample=NULL,pcAlign=TRUE,mc.cores=2) {
 
     m <- ncol(x)
     if (m == 2)
         x <- cbind(x,0)
     
-    xc <- apply(x,2,scale,scale=FALSE)
-    trans <- x[1,]-xc[1,]
-    pca <- prcomp(xc,scale. = F)
-    krdelta <- diag(3)
-    mirmat <- matrix(0,3,3)
-    a <- c(0,0,1)
-    anorm <- sum(a^2)
-    for (i in 1:3)
-        for (j in 1:3)
-            mirmat[i,j] <- 2*a[i]*a[j]/anorm
-
-    mirmat <- krdelta-mirmat
+    pca <- prcomp(x,scale. = F)
+    # i.e. a reflection along the z axis
+    mirmat <- diag(c(1,1,-1))
     out <- pca$x%*%t(mirmat)
-    xrot = getTrafoRotaxis(c(0,0,0),c(1,0,0),pi)
-    zrot = getTrafoRotaxis(c(0,0,0),c(0,0,1),pi)
-    pca2 <- prcomp(out)
-    test <- diag(pca2$rotation[,]%*%diag(3))
-    if (test[3] < 0 || test[1] < 0)##test if rotation around x-axis is needed to fix orientation
-        out <-  applyTransform(out,xrot)
     
-    if (icpiter > 0)
+    
+    if (pcAlign)
+        out <- pcAlign(out,pca$x,iterations=icpiter,subsample = subsample,mc.cores = mc.cores)
+    else if (icpiter > 0)
         out <- icpmat(out,pca$x,icpiter,subsample = subsample)
+    
     out <- out%*%t(pca$rotation)
-    out <- t(t(out)+trans)
+    out <- t(t(out)+pca$center)
     if (m == 2)
         out <- out[,1:2]
     return(out)
@@ -68,10 +59,10 @@ mirror.matrix <- function(x,icpiter=50,subsample=NULL) {
 
 #' @rdname mirror
 #' @export
-mirror.mesh3d <- function(x,icpiter=50,subsample=NULL) {
+mirror.mesh3d <- function(x,icpiter=50,subsample=NULL,pcAlign=TRUE,mc.cores=2) {
     mesh <- x
     x <- vert2points(mesh)
-    vb <- mirror(x,icpiter=icpiter,subsample=subsample)
+    vb <- mirror(x,icpiter=icpiter,subsample=subsample,pcAlign=pcAlign,mc.cores=mc.cores)
     mesh$vb[1:3,] <- t(vb)
     mesh <- invertFaces(mesh)
     return(mesh)    
@@ -86,7 +77,7 @@ mirror.mesh3d <- function(x,icpiter=50,subsample=NULL) {
 #' @param iterations integer: number of iterations
 #' @param mindist restrict valid points to be within this distance
 #' @param subsample use a subsample determined by kmean clusters to speed up computation
-#' @param scale logical: if TRUE, scaling is allowed
+#' @param type character: select the transform to be applied, can be "rigid","similarity" or "affine"
 #' @return returns the rotated landmarks
 #' @examples
 #' data(nose)
@@ -108,12 +99,13 @@ mirror.mesh3d <- function(x,icpiter=50,subsample=NULL) {
 #' lines(rbind(icpsort[i,],gorf.dat[i,,2]))
 #' @importFrom Rvcg vcgKDtree
 #' @export
-icpmat <- function(x,y,iterations,mindist=1e15,subsample=NULL,scale=FALSE) {
+icpmat <- function(x,y,iterations,mindist=1e15,subsample=NULL,type=c("rigid","similarity","affine")) {
     m <- ncol(x)
     if (m == 2) {
         x <- cbind(x,0)
         y <- cbind(y,0)
     }
+    type <- match.arg(type,c("rigid","similarity","affine"))
     if (!is.null(subsample)) {
         subsample <- min(nrow(x)-1,subsample)
         subs <- duplicated(kmeans(x,centers=subsample,iter.max =100)$cluster)
@@ -124,10 +116,13 @@ icpmat <- function(x,y,iterations,mindist=1e15,subsample=NULL,scale=FALSE) {
     for (i in 1:iterations) {
         clost <- vcgKDtree(y,xtmp,1)
         good <- which(clost$distance < mindist)
-        xtmp[,1:m] <- rotonmat(xtmp[,1:m],xtmp[good,1:m],y[clost$index[good],1:m],scale = scale,reflection=FALSE)
+        trafo <- computeTransform(y[clost$index[good],],xtmp[good,],type=type)
+        xtmp <- applyTransform(xtmp[,],trafo)
+    }
+    if (!is.null(subsample)) {
+        fintrafo <- computeTransform(xtmp[,],x[!subs,],type = type)
+        xtmp <- applyTransform(x,fintrafo)
     }
-    if (!is.null(subsample))
-        xtmp <- rotonmat(x[,1:m],x[!subs,1:m],xtmp[,1:m],scale=scale,reflection=FALSE)
     if (m == 2)
         xtmp <- xtmp[,1:2]
     return(xtmp)
