@@ -272,77 +272,83 @@ vec getBaryCent(vec point, int fptr, mat vb, umat it) {
 }
 // main function to handle in and output
 SEXP points2mesh(SEXP ref_,SEXP vb_, SEXP it_, SEXP normals_, SEXP clostInd_, SEXP sign_, SEXP bary_, SEXP method_) {
-  NumericMatrix Rref(ref_);//reference 
-  NumericMatrix Rvb(vb_);//target vertices
-  NumericMatrix Rnormals(normals_);//target normals
-  IntegerMatrix Rit(it_);//target faces
-  IntegerMatrix RclostInd(clostInd_);//face indices to search on
-  int nref = Rref.ncol();
-  bool sign = as<bool>(sign_);
-  bool bary = as<bool>(bary_);
-  int method = as<int>(method_);
-  mat ref(Rref.begin(), Rref.nrow(), Rref.ncol());
-  mat vb(Rvb.begin(),Rvb.nrow(),Rvb.ncol());
-  mat normals(Rnormals.begin(),Rnormals.nrow(),Rnormals.ncol());
-  imat it(Rit.begin(),Rit.nrow(),Rit.ncol());
-  umat itU = conv_to<umat>::from(it);// convert to unsigned
-  imat clostInd(RclostInd.begin(),RclostInd.nrow(),RclostInd.ncol());
-  umat clostIndU = conv_to<umat>::from(clostInd);// convert to unsigned
-  // check which faces are acutally searched
-  uvec uniclost = unique(clostIndU);
-  // calculate edges and stuff needed for point search
-  mat DAT = updateSearchStruct(vb,itU,uniclost);
-  mat closeMat = ref;
-  mat outnormals = ref;
-  mat barycoords = ref;
+  try {
+    NumericMatrix Rref(ref_);//reference 
+    NumericMatrix Rvb(vb_);//target vertices
+    NumericMatrix Rnormals(normals_);//target normals
+    IntegerMatrix Rit(it_);//target faces
+    IntegerMatrix RclostInd(clostInd_);//face indices to search on
+    int nref = Rref.ncol();
+    bool sign = as<bool>(sign_);
+    bool bary = as<bool>(bary_);
+    int method = as<int>(method_);
+    mat ref(Rref.begin(), Rref.nrow(), Rref.ncol());
+    mat vb(Rvb.begin(),Rvb.nrow(),Rvb.ncol());
+    mat normals(Rnormals.begin(),Rnormals.nrow(),Rnormals.ncol());
+    imat it(Rit.begin(),Rit.nrow(),Rit.ncol());
+    umat itU = conv_to<umat>::from(it);// convert to unsigned
+    imat clostInd(RclostInd.begin(),RclostInd.nrow(),RclostInd.ncol());
+    umat clostIndU = conv_to<umat>::from(clostInd);// convert to unsigned
+    // check which faces are acutally searched
+    uvec uniclost = unique(clostIndU);
+    // calculate edges and stuff needed for point search
+    mat DAT = updateSearchStruct(vb,itU,uniclost);
+    mat closeMat = ref;
+    mat outnormals = ref;
+    mat barycoords = ref;
   
-  ivec region(nref), faceptr(nref); region.zeros();faceptr.zeros();
-  vec dists(nref); dists.zeros();
-  for (int i=0; i < nref; ++i) {
-    mat tmpdat = DAT.cols(clostIndU.col(i));//select appropriate subset of DAT
-    vec tmpvec(3), weight(3); 
-    tmpvec.zeros();weight.zeros();
-    int faceptrtmp=0;
-    closeMat.col(i) = pt2mesh(ref.col(i), tmpdat, dists(i), faceptrtmp,region(i),method);
-    faceptr(i)=clostInd(faceptrtmp,i);
-    //get normal weights
-    for (int j =0; j < 2; ++j) {
-      vec tmpdiff = closeMat.col(i)-vb.col(it(j,faceptr(i)));
-      weight(j) = sqrt(dot(tmpdiff,tmpdiff));
-      if (weight(j) == 0.0) {
-	weight(j) = 1e12;
-      } else {
-	weight(j) = 1/weight(j);
+    ivec region(nref), faceptr(nref); region.zeros();faceptr.zeros();
+    vec dists(nref); dists.zeros();
+    for (int i=0; i < nref; ++i) {
+      mat tmpdat = DAT.cols(clostIndU.col(i));//select appropriate subset of DAT
+      vec tmpvec(3), weight(3); 
+      tmpvec.zeros();weight.zeros();
+      int faceptrtmp=0;
+      closeMat.col(i) = pt2mesh(ref.col(i), tmpdat, dists(i), faceptrtmp,region(i),method);
+      faceptr(i)=clostInd(faceptrtmp,i);
+      //get normal weights
+      for (int j =0; j < 2; ++j) {
+	vec tmpdiff = closeMat.col(i)-vb.col(it(j,faceptr(i)));
+	weight(j) = sqrt(dot(tmpdiff,tmpdiff));
+	if (weight(j) == 0.0) {
+	  weight(j) = 1e12;
+	} else {
+	  weight(j) = 1/weight(j);
+	}
       }
-    }
-    //get weighted normals
-    vec tmpnormal(3); tmpnormal.zeros();
+      //get weighted normals
+      vec tmpnormal(3); tmpnormal.zeros();
 
-    for (int j = 0; j < 3; j++) {
-      tmpnormal += weight(j)*normals.col(it(j,faceptr(i)));
-    }
-    double normlen = norm(tmpnormal,2);
-    if (normlen > 0) {
-      tmpnormal /= normlen;
-    }
-    outnormals.col(i) = tmpnormal;
-    // sign distances
-    if (sign) {
-      vec tmpdiff = closeMat.col(i) - ref.col(i);
-      double signo = dot(tmpdiff,tmpnormal);
-      if (signo < 0) 
-	dists(i) *= -1;
-    }
-    // get barycentric coords
-    if (bary)
-      barycoords.col(i) = getBaryCent(closeMat.col(i), faceptr(i), vb, itU);
-  }  
-  return Rcpp::List::create(Named("clost") = closeMat,
-			    Named("dists") = dists,
-			    Named("faceptr") = faceptr,
-			    Named("normals") = outnormals,
-			    Named("barycoords") = barycoords
-			    );
+      for (int j = 0; j < 3; j++) {
+	tmpnormal += weight(j)*normals.col(it(j,faceptr(i)));
+      }
+      double normlen = norm(tmpnormal,2);
+      if (normlen > 0) {
+	tmpnormal /= normlen;
+      }
+      outnormals.col(i) = tmpnormal;
+      // sign distances
+      if (sign) {
+	vec tmpdiff = closeMat.col(i) - ref.col(i);
+	double signo = dot(tmpdiff,tmpnormal);
+	if (signo < 0) 
+	  dists(i) *= -1;
+      }
+      // get barycentric coords
+      if (bary)
+	barycoords.col(i) = getBaryCent(closeMat.col(i), faceptr(i), vb, itU);
+    }  
+    return Rcpp::List::create(Named("clost") = closeMat,
+			      Named("dists") = dists,
+			      Named("faceptr") = faceptr,
+			      Named("normals") = outnormals,
+			      Named("barycoords") = barycoords
+			      );
+  } catch (std::exception& e) {
+    ::Rf_error( e.what());
+  } catch (...) {
+    ::Rf_error("unknown exception");
+  }
   
   
 }
